@@ -455,7 +455,9 @@ class PunctuationMode(object):
     NONE = 'none'
     """Don't read any punctuation character at all."""
     SOME = 'some'
-    """Only the user-defined punctuation characters are read.
+    """Only some of the user-defined punctuation characters are read."""
+    MOST = 'most'
+    """Only most of the user-defined punctuation characters are read.
 
     The set of characters is specified in Speech Dispatcher configuration.
 
@@ -839,10 +841,10 @@ class SSIPClient(object):
     def list_synthesis_voices(self):
         """Return names of all available voices for the current output module.
 
-        Returns a tuple of tripplets (name, language, dialect).
+        Returns a tuple of tripplets (name, language, variant).
 
-        'name' is a string, 'language' is an ISO 639-1 Alpha-2 language code
-        and 'dialect' is a string.  Language and dialect may be None.
+        'name' is a string, 'language' is an ISO 639-1 Alpha-2/3 language code
+        and 'variant' is a string.  Language and variant may be None.
 
         """
         try:
@@ -850,19 +852,19 @@ class SSIPClient(object):
         except SSIPCommandError:
             return ()
         def split(item):
-            name, lang, dialect = tuple(item.rsplit('\t', 3))
-            return (name, lang or None, dialect or None)
+            name, lang, variant = tuple(item.rsplit('\t', 3))
+            return (name, lang or None, variant or None)
         return tuple([split(item) for item in data])
 
     def set_language(self, language, scope=Scope.SELF):
         """Switch to a particular language for further speech commands.
 
         Arguments:
-          language -- two letter language code according to RFC 1766 as string.
+          language -- two/three letter language code according to RFC 1766 as string, possibly with a region qualification.
           scope -- see the documentation of this class.
             
         """
-        assert isinstance(language, str) and len(language) == 2
+        assert isinstance(language, str)
         self._conn.send_command('SET', scope, 'LANGUAGE', language)
 
     def get_language(self):
@@ -973,10 +975,17 @@ class SSIPClient(object):
           scope -- see the documentation of this class.
             
         """
-        assert value in (PunctuationMode.ALL, PunctuationMode.SOME,
-                         PunctuationMode.NONE), value
+        assert value in (PunctuationMode.ALL, PunctuationMode.MOST,
+                         PunctuationMode.SOME, PunctuationMode.NONE), value
         self._conn.send_command('SET', scope, 'PUNCTUATION', value)
 
+    def get_punctuation(self):
+        """Get the punctuation pronounciation level."""
+        code, msg, data = self._conn.send_command('GET', 'PUNCTUATION')
+        if data:
+            return data[0]
+        return None
+
     def set_spelling(self, value, scope=Scope.SELF):
         """Toogle the spelling mode or on off.
 
