@@ -170,7 +170,7 @@ class Tests:
 
     def version(self):
         """Print version and copyright info"""
-        report("spd-conf 0.9.1\n")
+        report("spd-conf 0.10.1\n")
         report(_("""Copyright (C) %d-%d Brailcom, o.p.s.
 This is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by
@@ -627,8 +627,8 @@ Do you want to keep it?"""), False)
              "mary-generic", "baratinoo"])
 
         self.default_language = question(
-            "Default language (two-letter iso language code like \"en\" or \"cs\")",
-            "en")
+            "Default language (two/three-letter iso language code like \"en\" or \"cs\", possibly with a region qualification.)",
+            "en-US")
 
         self.default_audio_method = question_with_suggested_answers(
             "Default audio output method",
